@@ -13,35 +13,37 @@ pub mod register {
 			core::ptr::read_volatile(register_address as *mut u8)
 		}
 	}
+}
 
-	/// register::read_bit(0, 0b0000_0001) returns 1
-	pub fn read_bit(position: u8, byte: u8) -> u8 {
+pub mod bit {
+    /// register::read_bit(0, 0b0000_0001) returns 1
+	pub fn read(position: u8, byte: u8) -> u8 {
 		(byte >> position) & 0x01
 	}
 
 	/// register::set_bit(0, 0b0000_0000) returns 0b0000_0001
-	pub fn set_bit(position: u8, byte: u8) -> u8 {
+	pub fn set(position: u8, byte: u8) -> u8 {
 		byte | (1 << position)
 	}
 
 	/// register::unset_bit(0, 0b0000_0001) returns 0b0000_0000
-	pub fn unset_bit(position: u8, byte: u8) -> u8 {
+	pub fn unset(position: u8, byte: u8) -> u8 {
 		byte | (0 << position)
 	}
 
-	/// register::toggle_bit(0, 0b0000_0000) returns 0b0000_0001
-	pub fn toggle_bit(position: u8, byte: u8) -> u8 {
+	/// register::toggle(0, 0b0000_0000) returns 0b0000_0001
+	pub fn toggle(position: u8, byte: u8) -> u8 {
 		byte ^ (1 << position)
 	}
 }
 
 
 pub mod convert {
-	use super::register;
+	use super::bit;
 
     /// Maps bit values from byte to '0' or '1'
 	pub fn bit_to_char(position: u8, byte: u8) -> char {
-		match register::read_bit(position, byte) as u8 {
+		match bit::read(position, byte) as u8 {
 			0 => '0',
 			1 => '1',
 			_ => '\0'
@@ -77,43 +79,43 @@ pub mod convert {
 
 #[cfg(test)]
 mod tests {
-    use super::register;
+    use super::bit;
     use super::convert;
 
     #[test]
-    fn test_register_read_bit() {
+    fn test_bit_read() {
         let byte: u8 = 0b1000_0001;
-        assert_eq!(register::read_bit(0, byte), 1);
-        assert_eq!(register::read_bit(1, byte), 0);
-        assert_eq!(register::read_bit(7, byte), 1);
+        assert_eq!(bit::read(0, byte), 1);
+        assert_eq!(bit::read(1, byte), 0);
+        assert_eq!(bit::read(7, byte), 1);
     }
 
     #[test]
-    fn test_register_set_bit() {
+    fn test_bit_set() {
         let mut byte: u8 = 0b0000_0000;
 
-        byte = register::set_bit(0, byte);
-        assert_eq!(register::read_bit(0, byte), 1);
+        byte = bit::set(0, byte);
+        assert_eq!(bit::read(0, byte), 1);
 
-        byte = register::set_bit(7, byte);
-        assert_eq!(register::read_bit(7, byte), 1);
+        byte = bit::set(7, byte);
+        assert_eq!(bit::read(7, byte), 1);
     }
 
     #[test]
-    fn test_register_toggle_bit() {
+    fn test_bit_toggle() {
         let mut byte: u8 = 0b0000_0000;
 
-        byte = register::toggle_bit(0, byte);
-        assert_eq!(register::read_bit(0, byte), 1);
+        byte = bit::toggle(0, byte);
+        assert_eq!(bit::read(0, byte), 1);
 
-        byte = register::toggle_bit(7, byte);
-        assert_eq!(register::read_bit(7, byte), 1);
+        byte = bit::toggle(7, byte);
+        assert_eq!(bit::read(7, byte), 1);
 
-        byte = register::toggle_bit(0, byte);
-        assert_eq!(register::read_bit(0, byte), 0);
+        byte = bit::toggle(0, byte);
+        assert_eq!(bit::read(0, byte), 0);
 
-        byte = register::toggle_bit(7, byte);
-        assert_eq!(register::read_bit(7, byte), 0);
+        byte = bit::toggle(7, byte);
+        assert_eq!(bit::read(7, byte), 0);
     }
 
     #[test]
